/**************************************************************************//**
 * @file     FlashDev.c
 * @brief    Flash Device Description for New Device Flash
 * @version  V1.0.0
 * @date     10. January 2018
 ******************************************************************************/
/*
 * Copyright (c) 2010-2018 Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
#include "..\FlashOS.H"        // FlashOS Structures

/**
	@attention User Guidance:	To generate a download algorithm, follow the steps to set it up
	1.Click Option->Output->Name of Executale and set output FLM file name (e.g. PT32L007x8x7 PT32L007x6x7).
	2.Click Option->C/C++->Preproress Symbol->Define and fill in " PT32L007x8x7 " or "PT32L007x6x7" macro definition.
	3.Ensure that the output file name is set as above, and the Device Size of " FlashDevice " Struct is set according to the Flash specifications.
	4.After compiling, the FLM file will be generated.
	@note PT32L007 Flash specification is available in 64KB/32KB type. 
**/ 

struct FlashDevice const FlashDevice  =  {
   FLASH_DRV_VERS,             // Driver Version, do not modify!
   "PT32L007x8x7",             // Device Name 
   ONCHIP,                     // Device Type
   0x00000000,                 // Device Start Address
   0x00010000,                 // Device Size in Bytes (64kB)
//   0x00008000,                 // Device Size in Bytes (32kB)	
   512,                        // Programming Page Size
   0,                          // Reserved, must be 0
   0xFF,                       // Initial Content of Erased Memory
   500,                        // Program Page Timeout 100 mSec
   500,                        // Erase Sector Timeout 3000 mSec

// Specify Size and Address of Sectors
   0x200, 0x000000,         // Sector Size
   SECTOR_END
};
