  /******************************************************************************
  * @file    PT32x007x_spi.c
  * @author  ӦÿŶ
  * @version V1.6.0
  * @date    2024/2/28
  * @brief    This file provides firmware functions to manage the following
  *          functionalities of the Serial peripheral interface (SPI):
  *           + Initialization and Configuration
  *           + Data transfers functions
  *           + Interrupts and flags management
  *            
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/
  
/* Includes ------------------------------------------------------------------*/
#include "PT32x007x_spi.h"
#include "spi_flash.h"
static __IO uint32_t  SPITimeout = SPIT_LONG_TIMEOUT; 
static  uint16_t Flash_TIMEOUT_UserCallback(uint8_t errorCode)
{
  /* ȴʱĴ,Ϣ */
  FLASH_ERROR("SPI ȴʱ!errorCode = %d",errorCode);
  return 0;
}
uint8_t SPI_FLASH_SendByte(SPI_TypeDef* SPIx,uint8_t byte)
{
	u16 SPITimeout;
	SPITimeout = SPIT_FLAG_TIMEOUT;
  /* ȴͻΪգTXE¼ */
	while((SPI->SR1&SPI_SR1_TXE)==0)
	{
    if((SPITimeout--) == 0)   
		{
			Flash_TIMEOUT_UserCallback(0);
		}
  }
  /* дݼĴҪдд뷢ͻ */
  SPI_SendData(SPIx , byte);

	SPITimeout = SPIT_FLAG_TIMEOUT;
  /* ȴջǿգRXNE¼ */
	while((SPI->SR1&SPI_SR1_RXNE)==0)
	{
    if((SPITimeout--) == 0)   
		{
			Flash_TIMEOUT_UserCallback(1);
		}
   }
  /* ȡݼĴȡջ */
  return SPI_ReceiveData(SPIx );
}


 /**
  * @brief  FLASH дʹ 
  * @param  none
  * @retval none
  */
void SPI_FLASH_WriteEnable(SPI_TypeDef* SPIx)
{
  /* ͨѶʼCS */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_Low);

  /* дʹ*/
  SPI_FLASH_SendByte(SPIx ,W25X_WriteEnable);

  /*ͨѶCS */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_High);
}

/* WIP(busy)־FLASHڲд */
#define WIP_Flag                  0x01

 /**
  * @brief  ȴWIP(BUSY)־0ȴFLASHڲд
  * @param  none
  * @retval none
  */
void SPI_FLASH_WaitForWriteEnd(SPI_TypeDef* SPIx)
{
  uint8_t FLASH_Status = 0;

  /* ѡ FLASH: CS  */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_Low);

  /*  ״̬Ĵ  */
  SPI_FLASH_SendByte(SPIx ,W25X_ReadStatusReg);

  /* FLASHæµȴ */
  do
  {
		/* ȡFLASHоƬ״̬Ĵ */
    FLASH_Status = SPI_FLASH_SendByte(SPIx ,Dummy_Byte);	 
  }
  while ((FLASH_Status & WIP_Flag) == SET);  /* д־ */

  /* ֹͣź  FLASH: CS  */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_High);
}

/*----------------------------------------------*/

uint32_t SPI_FLASH_ReadID(SPI_TypeDef* SPIx)
{
  uint32_t Temp = 0, Temp0 = 0, Temp1 = 0, Temp2 = 0;
  /* ʼͨѶCS͵ƽ */   
	SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_Low);
  /* JEDECָȡID */
  SPI_FLASH_SendByte(SPIx,W25X_JedecDeviceID);
  /* ȡһֽ */
  Temp0 = SPI_FLASH_SendByte(SPIx,0x00);
  /* ȡһֽ */
  Temp1 = SPI_FLASH_SendByte(SPIx,0x00);
  /* ȡһֽ */
  Temp2 = SPI_FLASH_SendByte(SPIx,0x00);
 /* ֹͣͨѶCSߵƽ */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_High);

  /*Ϊķֵ*/
	Temp = (Temp0 << 16) | (Temp1 << 8) | Temp2;
  return Temp;
}
void SPI_Flash_ReadByte(SPI_TypeDef* SPIx,u32 addr)
{
	u8 data[10]={0},i;
	/* ʼͨѶCS͵ƽ */   
	SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_Low);
  /* ָȡ */
  SPI_FLASH_SendByte(SPIx,W25X_ReadData);
  SPI_FLASH_SendByte(SPIx,(addr&0xFF0000)>>16);
  SPI_FLASH_SendByte(SPIx,(addr&0xFF00)>>8);
  SPI_FLASH_SendByte(SPIx,addr&0xFF);
	for(i=0;i<10;i++)
	{
  	data[i]=SPI_FLASH_SendByte(SPIx,Dummy_Byte);
	}
	printf("address: 0x%X\r\n",addr);
	for(i=0;i<10;i++)
	{
  	printf("read data%d:0x%X\r\n",i,data[i]);
		while(!UART_GetFlagStatus(UART0,UART_FLAG_TXE));
	}
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_High);
}
void SPI_Flash_SectorErase(SPI_TypeDef* SPIx,u32 addr)
{
	//ִдʹ
	SPI_FLASH_WriteEnable(SPI);
  //
	SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_Low);
  SPI_FLASH_SendByte(SPIx,W25X_SectorErase);
  SPI_FLASH_SendByte(SPIx,(addr&0xFF0000)>>16);
  SPI_FLASH_SendByte(SPIx,(addr&0xFF00)>>8);
  SPI_FLASH_SendByte(SPIx,addr&0xFF);
	SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_High);
	SPI_FLASH_WaitForWriteEnd(SPI);
}
void SPI_Flash_WriteByte(SPI_TypeDef* SPIx,u32 addr)
{
	u8 i,data[10]={0};
	//ִдʹ
	SPI_FLASH_WriteEnable(SPI);
	//д
	SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_Low);
  SPI_FLASH_SendByte(SPIx,W25X_PageProgram);
  SPI_FLASH_SendByte(SPIx,(addr&0xFF0000)>>16);
  SPI_FLASH_SendByte(SPIx,(addr&0xFF00)>>8);
  SPI_FLASH_SendByte(SPIx,addr&0xFF);
	for(i=0;i<10;i++)
	{
		data[i]=i;
	  SPI_FLASH_SendByte(SPIx,data[i]);	
	}
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_High);
	SPI_FLASH_WaitForWriteEnd(SPI);
}

